/*
 * Copyright (c) Microsoft Corporation.
 * Licensed under the MIT License.
 *
 * Code generated by Microsoft (R) AutoRest Code Generator.
 * Changes may cause incorrect behavior and will be lost if the code is regenerated.
 */
import { __asyncDelegator, __asyncGenerator, __asyncValues, __await } from "tslib";
import * as coreClient from "@azure/core-client";
import * as Mappers from "../models/mappers";
import * as Parameters from "../models/parameters";
/// <reference lib="esnext.asynciterable" />
/** Class containing VpnSiteLinks operations. */
export class VpnSiteLinksImpl {
    /**
     * Initialize a new instance of the class VpnSiteLinks class.
     * @param client Reference to the service client
     */
    constructor(client) {
        this.client = client;
    }
    /**
     * Lists all the vpnSiteLinks in a resource group for a vpn site.
     * @param resourceGroupName The resource group name of the VpnSite.
     * @param vpnSiteName The name of the VpnSite.
     * @param options The options parameters.
     */
    listByVpnSite(resourceGroupName, vpnSiteName, options) {
        const iter = this.listByVpnSitePagingAll(resourceGroupName, vpnSiteName, options);
        return {
            next() {
                return iter.next();
            },
            [Symbol.asyncIterator]() {
                return this;
            },
            byPage: () => {
                return this.listByVpnSitePagingPage(resourceGroupName, vpnSiteName, options);
            }
        };
    }
    listByVpnSitePagingPage(resourceGroupName, vpnSiteName, options) {
        return __asyncGenerator(this, arguments, function* listByVpnSitePagingPage_1() {
            let result = yield __await(this._listByVpnSite(resourceGroupName, vpnSiteName, options));
            yield yield __await(result.value || []);
            let continuationToken = result.nextLink;
            while (continuationToken) {
                result = yield __await(this._listByVpnSiteNext(resourceGroupName, vpnSiteName, continuationToken, options));
                continuationToken = result.nextLink;
                yield yield __await(result.value || []);
            }
        });
    }
    listByVpnSitePagingAll(resourceGroupName, vpnSiteName, options) {
        return __asyncGenerator(this, arguments, function* listByVpnSitePagingAll_1() {
            var e_1, _a;
            try {
                for (var _b = __asyncValues(this.listByVpnSitePagingPage(resourceGroupName, vpnSiteName, options)), _c; _c = yield __await(_b.next()), !_c.done;) {
                    const page = _c.value;
                    yield __await(yield* __asyncDelegator(__asyncValues(page)));
                }
            }
            catch (e_1_1) { e_1 = { error: e_1_1 }; }
            finally {
                try {
                    if (_c && !_c.done && (_a = _b.return)) yield __await(_a.call(_b));
                }
                finally { if (e_1) throw e_1.error; }
            }
        });
    }
    /**
     * Retrieves the details of a VPN site link.
     * @param resourceGroupName The resource group name of the VpnSite.
     * @param vpnSiteName The name of the VpnSite.
     * @param vpnSiteLinkName The name of the VpnSiteLink being retrieved.
     * @param options The options parameters.
     */
    get(resourceGroupName, vpnSiteName, vpnSiteLinkName, options) {
        return this.client.sendOperationRequest({ resourceGroupName, vpnSiteName, vpnSiteLinkName, options }, getOperationSpec);
    }
    /**
     * Lists all the vpnSiteLinks in a resource group for a vpn site.
     * @param resourceGroupName The resource group name of the VpnSite.
     * @param vpnSiteName The name of the VpnSite.
     * @param options The options parameters.
     */
    _listByVpnSite(resourceGroupName, vpnSiteName, options) {
        return this.client.sendOperationRequest({ resourceGroupName, vpnSiteName, options }, listByVpnSiteOperationSpec);
    }
    /**
     * ListByVpnSiteNext
     * @param resourceGroupName The resource group name of the VpnSite.
     * @param vpnSiteName The name of the VpnSite.
     * @param nextLink The nextLink from the previous successful call to the ListByVpnSite method.
     * @param options The options parameters.
     */
    _listByVpnSiteNext(resourceGroupName, vpnSiteName, nextLink, options) {
        return this.client.sendOperationRequest({ resourceGroupName, vpnSiteName, nextLink, options }, listByVpnSiteNextOperationSpec);
    }
}
// Operation Specifications
const serializer = coreClient.createSerializer(Mappers, /* isXml */ false);
const getOperationSpec = {
    path: "/subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/vpnSites/{vpnSiteName}/vpnSiteLinks/{vpnSiteLinkName}",
    httpMethod: "GET",
    responses: {
        200: {
            bodyMapper: Mappers.VpnSiteLink
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    queryParameters: [Parameters.apiVersion],
    urlParameters: [
        Parameters.$host,
        Parameters.resourceGroupName,
        Parameters.subscriptionId,
        Parameters.vpnSiteName,
        Parameters.vpnSiteLinkName
    ],
    headerParameters: [Parameters.accept],
    serializer
};
const listByVpnSiteOperationSpec = {
    path: "/subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Network/vpnSites/{vpnSiteName}/vpnSiteLinks",
    httpMethod: "GET",
    responses: {
        200: {
            bodyMapper: Mappers.ListVpnSiteLinksResult
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    queryParameters: [Parameters.apiVersion],
    urlParameters: [
        Parameters.$host,
        Parameters.resourceGroupName,
        Parameters.subscriptionId,
        Parameters.vpnSiteName
    ],
    headerParameters: [Parameters.accept],
    serializer
};
const listByVpnSiteNextOperationSpec = {
    path: "{nextLink}",
    httpMethod: "GET",
    responses: {
        200: {
            bodyMapper: Mappers.ListVpnSiteLinksResult
        },
        default: {
            bodyMapper: Mappers.CloudError
        }
    },
    queryParameters: [Parameters.apiVersion],
    urlParameters: [
        Parameters.$host,
        Parameters.resourceGroupName,
        Parameters.subscriptionId,
        Parameters.nextLink,
        Parameters.vpnSiteName
    ],
    headerParameters: [Parameters.accept],
    serializer
};
//# sourceMappingURL=vpnSiteLinks.js.map