import { PagedAsyncIterableIterator } from "@azure/core-paging";
import { PrivateZones } from "../operationsInterfaces";
import { PrivateDnsManagementClient } from "../privateDnsManagementClient";
import { PollerLike, PollOperationState } from "@azure/core-lro";
import { PrivateZone, PrivateZonesListOptionalParams, PrivateZonesListByResourceGroupOptionalParams, PrivateZonesCreateOrUpdateOptionalParams, PrivateZonesCreateOrUpdateResponse, PrivateZonesUpdateOptionalParams, PrivateZonesUpdateResponse, PrivateZonesDeleteOptionalParams, PrivateZonesGetOptionalParams, PrivateZonesGetResponse } from "../models";
/** Class containing PrivateZones operations. */
export declare class PrivateZonesImpl implements PrivateZones {
    private readonly client;
    /**
     * Initialize a new instance of the class PrivateZones class.
     * @param client Reference to the service client
     */
    constructor(client: PrivateDnsManagementClient);
    /**
     * Lists the Private DNS zones in all resource groups in a subscription.
     * @param options The options parameters.
     */
    list(options?: PrivateZonesListOptionalParams): PagedAsyncIterableIterator<PrivateZone>;
    private listPagingPage;
    private listPagingAll;
    /**
     * Lists the Private DNS zones within a resource group.
     * @param resourceGroupName The name of the resource group.
     * @param options The options parameters.
     */
    listByResourceGroup(resourceGroupName: string, options?: PrivateZonesListByResourceGroupOptionalParams): PagedAsyncIterableIterator<PrivateZone>;
    private listByResourceGroupPagingPage;
    private listByResourceGroupPagingAll;
    /**
     * Creates or updates a Private DNS zone. Does not modify Links to virtual networks or DNS records
     * within the zone.
     * @param resourceGroupName The name of the resource group.
     * @param privateZoneName The name of the Private DNS zone (without a terminating dot).
     * @param parameters Parameters supplied to the CreateOrUpdate operation.
     * @param options The options parameters.
     */
    beginCreateOrUpdate(resourceGroupName: string, privateZoneName: string, parameters: PrivateZone, options?: PrivateZonesCreateOrUpdateOptionalParams): Promise<PollerLike<PollOperationState<PrivateZonesCreateOrUpdateResponse>, PrivateZonesCreateOrUpdateResponse>>;
    /**
     * Creates or updates a Private DNS zone. Does not modify Links to virtual networks or DNS records
     * within the zone.
     * @param resourceGroupName The name of the resource group.
     * @param privateZoneName The name of the Private DNS zone (without a terminating dot).
     * @param parameters Parameters supplied to the CreateOrUpdate operation.
     * @param options The options parameters.
     */
    beginCreateOrUpdateAndWait(resourceGroupName: string, privateZoneName: string, parameters: PrivateZone, options?: PrivateZonesCreateOrUpdateOptionalParams): Promise<PrivateZonesCreateOrUpdateResponse>;
    /**
     * Updates a Private DNS zone. Does not modify virtual network links or DNS records within the zone.
     * @param resourceGroupName The name of the resource group.
     * @param privateZoneName The name of the Private DNS zone (without a terminating dot).
     * @param parameters Parameters supplied to the Update operation.
     * @param options The options parameters.
     */
    beginUpdate(resourceGroupName: string, privateZoneName: string, parameters: PrivateZone, options?: PrivateZonesUpdateOptionalParams): Promise<PollerLike<PollOperationState<PrivateZonesUpdateResponse>, PrivateZonesUpdateResponse>>;
    /**
     * Updates a Private DNS zone. Does not modify virtual network links or DNS records within the zone.
     * @param resourceGroupName The name of the resource group.
     * @param privateZoneName The name of the Private DNS zone (without a terminating dot).
     * @param parameters Parameters supplied to the Update operation.
     * @param options The options parameters.
     */
    beginUpdateAndWait(resourceGroupName: string, privateZoneName: string, parameters: PrivateZone, options?: PrivateZonesUpdateOptionalParams): Promise<PrivateZonesUpdateResponse>;
    /**
     * Deletes a Private DNS zone. WARNING: All DNS records in the zone will also be deleted. This
     * operation cannot be undone. Private DNS zone cannot be deleted unless all virtual network links to
     * it are removed.
     * @param resourceGroupName The name of the resource group.
     * @param privateZoneName The name of the Private DNS zone (without a terminating dot).
     * @param options The options parameters.
     */
    beginDelete(resourceGroupName: string, privateZoneName: string, options?: PrivateZonesDeleteOptionalParams): Promise<PollerLike<PollOperationState<void>, void>>;
    /**
     * Deletes a Private DNS zone. WARNING: All DNS records in the zone will also be deleted. This
     * operation cannot be undone. Private DNS zone cannot be deleted unless all virtual network links to
     * it are removed.
     * @param resourceGroupName The name of the resource group.
     * @param privateZoneName The name of the Private DNS zone (without a terminating dot).
     * @param options The options parameters.
     */
    beginDeleteAndWait(resourceGroupName: string, privateZoneName: string, options?: PrivateZonesDeleteOptionalParams): Promise<void>;
    /**
     * Gets a Private DNS zone. Retrieves the zone properties, but not the virtual networks links or the
     * record sets within the zone.
     * @param resourceGroupName The name of the resource group.
     * @param privateZoneName The name of the Private DNS zone (without a terminating dot).
     * @param options The options parameters.
     */
    get(resourceGroupName: string, privateZoneName: string, options?: PrivateZonesGetOptionalParams): Promise<PrivateZonesGetResponse>;
    /**
     * Lists the Private DNS zones in all resource groups in a subscription.
     * @param options The options parameters.
     */
    private _list;
    /**
     * Lists the Private DNS zones within a resource group.
     * @param resourceGroupName The name of the resource group.
     * @param options The options parameters.
     */
    private _listByResourceGroup;
    /**
     * ListNext
     * @param nextLink The nextLink from the previous successful call to the List method.
     * @param options The options parameters.
     */
    private _listNext;
    /**
     * ListByResourceGroupNext
     * @param resourceGroupName The name of the resource group.
     * @param nextLink The nextLink from the previous successful call to the ListByResourceGroup method.
     * @param options The options parameters.
     */
    private _listByResourceGroupNext;
}
//# sourceMappingURL=privateZones.d.ts.map